/**
 * JHOVE2 - Next-generation architecture for format-aware characterization
 *
 * Copyright (c) 2009 by The Regents of the University of California,
 * Ithaka Harbors, Inc., and The Board of Trustees of the Leland Stanford
 * Junior University.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * o Redistributions of source code must retain the above copyright notice,
 *   this list of conditions and the following disclaimer.
 *
 * o Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 *
 * o Neither the name of the University of California/California Digital
 *   Library, Ithaka Harbors/Portico, or Stanford University, nor the names of
 *   its contributors may be used to endorse or promote products derived from
 *   this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.jhove2.module.format;

import org.jhove2.annotation.ReportableProperty;
import org.jhove2.core.JHOVE2Exception;
import org.jhove2.core.format.Format;
import org.jhove2.module.Module;

/**
 * Interface for JHOVE2 format profiles, which are
 * {@link org.jhove2.module.Module}s that model a specific format in a format
 * family.
 * 
 * @author mstrong, slabrams, smorrissey
 */
public interface FormatProfile
	extends Module, Validator
{
	/**
	 * Get format profile format.
	 * @return Format profile format
	 */
	@ReportableProperty("Format profile format.")
	public Format getFormat();
	/** Set format profile format.
	 * @param format Format profile format
	 */
	public void setFormat(Format format);
	/**
	 * Set Format Module to which Profile belongs
	 * @param formatModule Format Module to which Profile belongs
	 * @return FormatModule
	 * @throws JHOVE2Exception
	 */
	public FormatProfile setFormatModule(FormatModule formatModule) 
    throws JHOVE2Exception;

	/**
	 * Get FormatModule of which this is a profile
	 * @return FormatModule 
	 * @throws JHOVE2Exception
	 */
	public FormatModule getFormatModule() throws JHOVE2Exception;
	
	/**
	 * @return the formatModuleId
	 */
	public Long getFormatModuleId();
	


	/**
	 * @param formatModuleId the formatModuleId to set
	 */
	public void setFormatModuleId(Long formatModuleId);

}
